@@ -131,7 +131,7 @@ class FastInferenceInterface:
         logger.info(f"together_request {raw_event}")
         loop = asyncio.get_event_loop()
         request_json = [event["match"]["service_bid"]["job"] for event in raw_event]
-        if request_json[0]["request_type"] == RequestTypeShutdown:
+        if request_json[0].get("request_type", "") == RequestTypeShutdown:
             self.dispatch_shutdown()
         response_json = await loop.run_in_executor(self.executor, self.dispatch_request, request_json, match_event)
         response_json = response_json if isinstance(response_json, list) else [response_json]
